@@ -1461,7 +1461,9 @@ class TestTablesClient(object):
             "google.cloud.automl_v1beta1.gapic.prediction_service_client.PredictionServiceClient"
         )
         with patch_prediction_client as MockPredictionClient:
-            client = automl_v1beta1.TablesClient(client_info=client_info_mock)
+            client = automl_v1beta1.TablesClient(
+                client_info=client_info_mock, credentials=AnonymousCredentials()
+            )
         _, prediction_client_kwargs = MockPredictionClient.call_args
         assert "client_info" in prediction_client_kwargs
         assert prediction_client_kwargs["client_info"] == client_info_mock
